import { Link } from '@inertiajs/react';
import Card from '@/Components/Card';
import Badge from '@/Components/Badge';
import { motion } from "framer-motion";
import Pagination from '@/Components/Pagination';

export default function FunnelList({ funnels }) {
    return (
        <>
            <div className='grid lg:grid-cols-4 md:grid-cols-3 grid-cols-1 gap-1'>
                {funnels.data.map((funnel, index) => (
                    <Link href={route('sdr.settings.funnel.details', funnel.id)} key={index}>
                        <motion.div initial={{ opacity: 0 }} animate={{ opacity: 1 }} transition={{ duration: 0.5, delay: index * 0.05 }}>
                            <Card className="hover:bg-hover-default hover:bg-opacity-40">
                                <p className="text-sm font-semibold">{funnel.name}</p>
                                <p className="text-[.8rem]">{funnel.stages.length} etapas</p>

                                <div className="flex justify-between items-center border-t border-border mt-3 pt-3">
                                    <Badge type={funnel.is_active === 1 ? 'success' : 'danger'} title={funnel.is_active === 1 ? 'Ativo' : 'Inativo'} />

                                    {funnel.is_default === 1 && <Badge title='Principal' />}
                                </div>
                            </Card>
                        </motion.div>
                    </Link>
                ))}
            </div>

            {funnels.data.length >= 40 && <Pagination links={funnels.meta.links} />}
        </>
    );
};
